App class

Constructors

App(String header, {String? left = 'Left', String? right = 'Right', String? enter = 'Enter', dynamic onLeft(App app)?, dynamic onRight(App app)?, dynamic onEnter(App app)?})

Properties

enter String?
final
focused int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
left String?
final
onEnter → dynamic Function(App app)?
final
onLeft → dynamic Function(App app)?
final
onRight → dynamic Function(App app)?
final
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addButtons(List<String> buttons) → void
addDivider(String title) → void
addMenuItem(String title, {String? subtitle, VoidCallback? onClick}) → void
addText(String text) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
showToast(String message) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited